Deconvolve Restoration
-----------------------


Lucy-Richardson
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Procedural API
    .. currentmodule:: aydin

    .. autofunction:: lucyrichardson

Object-Oriented API:
    .. currentmodule:: aydin.restoration.deconvolve.lr

    .. autoclass:: LucyRichardson
       :members:
       :inherited-members: